/* Program: SegregateOrIntegrate.do
*
* Author: Simeon D. Alder (UCLA)
*
* Project: de la Croix and Doepke, "To Segregate or to Integrate: Education Politics and Democracy",
* July 2008
*
* Date of Creation: 8/7/2007
*
* Date of Most Recent Modification: 8/17/2008
*
* Program Description:
* Generate household-level data from a 1% sample of the 2000 US Census with both person-level and
* household-level variables. The data is made available by Steven Ruggles, Matthew Sobek, Trent
* Alexander, Catherine A. Fitch, Ronald Goeken, Patricia Kelly Hall, Miriam King, and Chad Ronnander. 
* Integrated Public Use Microdata Series: Version 4.0 [Machine-readable database]. Minneapolis, MN:
* Minnesota Population Center [producer and distributor], 2008. The data is available online at:
* http://usa.ipums.org/usa
* Using the household-level variables, we can compute the correlations reported in Table 1, as well
* as the regressions in Tables 2 and 3. */

clear

/* The size of the data set with all necessary variables is approximately 118 MB. The data
* management tasks as well as the regressions must be carried out on hardware with sufficient
* memory; the computations as they are reported in the paper were carried out on a UNIX-server
* and the amount of memory set aside for STATA-SE was 5 GB. */

/* The data set was saved as 'IPUMSextract.dta' and is referred to as such in this do-file. If you
* save it under a different name, make sure you adapt the do-file accordingly. */

set mem 5000m
set more off

/* Following is a list of variables that must be included in the dataset (1% sample of the 2000
* Census) in order to carry out all the commands in this do file:

* YEAR
* SERIAL
* NUMPREC
* HHWT
* STATEFIP
* GQ
* METRO
* HHINCOME
* PERNUM
* NCHILD
* RELATE
* AGE
* HISPAND
* RACAMIND
* RACASIAN
* RACBLK
* RACPACIS
* RACWHT
* RACOTHER
* SCHOOL
* SCHLTYPE */

/* We also need to install a program file called 'estout.ado' in order to export estimates into
* text files. This program by Ben Jann (2004) is available from:
* http://econpapers.repec.org/software/bocbocode/s439301.htm.
* This module may also be installed from within STATA by typing "ssc install estout".
* Windows users should not attempt to download these files with a web browser. */

ssc install estout

/* Load the data set into the memory set aside for STATA. For simplicity, save the data set in the
* working directory (check your version of STATA to identify the working directory). */

use IPUMSextract.dta, replace

/* Generate dummy variables that are relevant for household's schooling decision. */

/* Dummy: 1 if child is school age (4-18) */
gen kid = 0
replace kid = 1 if age<19 & age>3

/* Dummy: 1 if child is in school */
gen kidInSchool = 0
replace kidInSchool = 1 if school==2 & kid==1

/* Note: adults could also be in school, but the schooling decision in this model
* is concerned with the parents' schooling choice for their children, not for themselves. */

/* Dummy: 1 if child is in private school */
gen kidInPrivateSchool = 0
replace kidInPrivateSchool = 1 if kidInSchool==1 & schltype==3

/* Generate new variable with age of head of household: 'HHHage'.
* Since we aggregate data to the HH level using the 'collapse(mean)' command, I will 
* multiply the age by the number of people in the household; since we divide by the number
* of people when collapsing, this generates the correct age for the head of household. */

gen HHHage = 0
replace HHHage = age*numprec if relate==1

/* Generate new variable with race (including hispanic origin) of head of household.
* I shall label them 'HHHraceAsian', 'HHHraceBlk', etc.
* Since we aggregate the person-level data to the household level using 'collapse(mean)', I
* multiply the race dummy by the number people in the household, as we did for 'HHHage'.
* The base case is 'white', so we have dummies for the other races plus 'Hispanic origin'.
* Heads of households are Hispanic if they indicate to be of 'Hispanic origin'; we ignore the
* race dummies in this case. */ 

gen HHHraceAsian = 0
replace HHHraceAsian = numprec if racasian==2 & relate==1 & hispand==000
gen HHHraceBlk = 0
replace HHHraceBlk = numprec if racblk==2 & relate==1 & hispand==000
gen HHHracePacis = 0
replace HHHracePacis = numprec if racpacis==2 & relate==1 & hispand==000
gen HHHraceAmind = 0
replace HHHraceAmind = numprec if racamind==2 & relate==1 & hispand==000
gen HHHraceHisp = 0
replace HHHraceHisp = numprec if hispand!=000 & relate==1
gen HHHraceOther = 0
replace HHHraceOther = numprec if racother==2 & relate==1 & hispand==000
gen HHHraceWhite = 0
replace HHHraceWhite = numprec if racwht==2 & relate==1 & hispand==000

/* Add state-level data on public education spending per capita.
* Source: US Department of Commerce, Bureau of the Census, unpublished data (September 2001). */

gen PubEdExpPerCap = 0
replace PubEdExpPerCap = 1524 if statefip==1
replace PubEdExpPerCap = 2491 if statefip==2
replace PubEdExpPerCap = 1396 if statefip==4
replace PubEdExpPerCap = 1476 if statefip==5
replace PubEdExpPerCap = 1597 if statefip==6
replace PubEdExpPerCap = 1721 if statefip==8
replace PubEdExpPerCap = 1666 if statefip==9
replace PubEdExpPerCap = 2023 if statefip==10
replace PubEdExpPerCap = 1448 if statefip==11
replace PubEdExpPerCap = 1319 if statefip==12
replace PubEdExpPerCap = 1611 if statefip==13
replace PubEdExpPerCap = 1375 if statefip==15
replace PubEdExpPerCap = 1564 if statefip==16
replace PubEdExpPerCap = 1601 if statefip==17
replace PubEdExpPerCap = 1732 if statefip==18
replace PubEdExpPerCap = 1908 if statefip==19
replace PubEdExpPerCap = 1656 if statefip==20
replace PubEdExpPerCap = 1417 if statefip==21
replace PubEdExpPerCap = 1452 if statefip==22
replace PubEdExpPerCap = 1627 if statefip==23
replace PubEdExpPerCap = 1664 if statefip==24
replace PubEdExpPerCap = 1597 if statefip==25
replace PubEdExpPerCap = 2021 if statefip==26
replace PubEdExpPerCap = 1914 if statefip==27
replace PubEdExpPerCap = 1489 if statefip==28
replace PubEdExpPerCap = 1474 if statefip==29
replace PubEdExpPerCap = 1666 if statefip==30
replace PubEdExpPerCap = 1787 if statefip==31
replace PubEdExpPerCap = 1468 if statefip==32
replace PubEdExpPerCap = 1523 if statefip==33
replace PubEdExpPerCap = 1999 if statefip==34
replace PubEdExpPerCap = 1793 if statefip==35
replace PubEdExpPerCap = 1981 if statefip==36
replace PubEdExpPerCap = 1580 if statefip==37
replace PubEdExpPerCap = 1781 if statefip==38
replace PubEdExpPerCap = 1624 if statefip==39
replace PubEdExpPerCap = 1535 if statefip==40
replace PubEdExpPerCap = 1791 if statefip==41
replace PubEdExpPerCap = 1740 if statefip==42
replace PubEdExpPerCap = 1671 if statefip==44
replace PubEdExpPerCap = 1590 if statefip==45
replace PubEdExpPerCap = 1436 if statefip==46
replace PubEdExpPerCap = 1343 if statefip==47
replace PubEdExpPerCap = 1667 if statefip==48
replace PubEdExpPerCap = 1828 if statefip==49
replace PubEdExpPerCap = 1983 if statefip==50
replace PubEdExpPerCap = 1631 if statefip==51
replace PubEdExpPerCap = 1834 if statefip==53
replace PubEdExpPerCap = 1581 if statefip==54
replace PubEdExpPerCap = 1991 if statefip==55
replace PubEdExpPerCap = 2099 if statefip==56

/* 'nchild' is a person-level variable. We need to identify those individuals who are heads of
* household (HHH, i.e. relate==1) and who have children. Then we need to generate a variable for
* the number of children by the HHH and multiply that number by 'numprec' so that we can keep
* track of those kids after we aggregate to the household level. */

gen HHnchild = 0
replace HHnchild = nchild*numprec if relate==1

/* At this point, we want to aggregate the data using the 'collapse (mean)' command; 'by(serial)'
* (at the very end of the command) collapses the data to the household level. */

collapse (mean) hhwt statefip gq hhincome kidInSchool kidInPrivateSchool HHnchild HHHage PubEdExpPerCap HHHraceAsian HHHraceBlk HHHracePacis HHHraceAmind HHHraceHisp HHHraceOther HHHraceWhite, by(serial)

/* Note: since we use the 'mean' option for the collapse command, this procedure normalizes the
* household size to unity (in terms of number of children). Since we have preserved the household
* weigh ('hhwt') in the aggregated data set, the sample continues to be representative, as long as
* the observations are weighted properly in the regressions. */

/* Since 'statefip' is not coded in increments of unity, we recode 'statefip' in order to
* run loops more easily. */

replace statefip=3 if statefip==51
replace statefip=7 if statefip==53
replace statefip=14 if statefip==54
replace statefip=43 if statefip==55
replace statefip=51 if statefip==56

/* Generate state dummies: */

forvalues i=1(1)51 {
	gen state`i'=0
	replace state`i'=1 if statefip==`i'
}

/* Generate age dummies: */

forvalues i=20(1)65 {
	gen age`i'=0
	replace age`i'=1 if HHHage==`i'
}
gen age15_19 = 0
replace age15_19 = 1 if HHHage < 20 & HHHage > 14

gen age66plus = 0
replace age66plus = 1 if HHHage > 65

/* Compute percentage of school-age kids in private school: */

gen pctPrivSchool = 0
replace pctPrivSchool = kidInPrivateSchool/kidInSchool if kidInSchool != 0

/* Note: pctPrivSchool = 0 means (a) household has no kids in school at all, or (b) household
* has no kids in private school. */

/* Generate cutoff dummy for different percentages of share of privately-schooled children: */

gen private = 0
replace private = 1 if pctPrivSchool > .5

/* Generate log of (household income + $10). */

gen hhincome10 = hhincome + 10
gen loghhincome10 = ln(hhincome10)

/* Drop observations with 'HHHage==0'. */
drop if HHHage==0

/* Total Current Expenditure Per Student (2000), Source: National Center for Education Statistics, CCD database. */

gen PESps = 0
replace PESps = 5885 if statefip==1
replace PESps = 9216 if statefip==2
replace PESps = 7281 if statefip==3
replace PESps = 5521 if statefip==4
replace PESps = 5568 if statefip==5
replace PESps = 6987 if statefip==6
replace PESps = 6750 if statefip==7
replace PESps = 6567 if statefip==8
replace PESps = 10127 if statefip==9
replace PESps = 8958 if statefip==10
replace PESps = 12046 if statefip==11
replace PESps = 6170 if statefip==12
replace PESps = 6929 if statefip==13
replace PESps = 7534 if statefip==14
replace PESps = 6596 if statefip==15
replace PESps = 5725 if statefip==16
replace PESps = 7631 if statefip==17
replace PESps = 7630 if statefip==18
replace PESps = 6930 if statefip==19
replace PESps = 6937 if statefip==20
replace PESps = 6079 if statefip==21
replace PESps = 6037 if statefip==22
replace PESps = 8232 if statefip==23
replace PESps = 8260 if statefip==24
replace PESps = 9509 if statefip==25
replace PESps = 8278 if statefip==26
replace PESps = 7645 if statefip==27
replace PESps = 5175 if statefip==28
replace PESps = 6657 if statefip==29
replace PESps = 6726 if statefip==30
replace PESps = 7223 if statefip==31
replace PESps = 5807 if statefip==32
replace PESps = 7286 if statefip==33
replace PESps = 11248 if statefip==34
replace PESps = 6313 if statefip==35
replace PESps = 10716 if statefip==36
replace PESps = 6340 if statefip==37
replace PESps = 6125 if statefip==38
replace PESps = 7571 if statefip==39
replace PESps = 6019 if statefip==40
replace PESps = 7528 if statefip==41
replace PESps = 8210 if statefip==42
replace PESps = 8243 if statefip==43
replace PESps = 9315 if statefip==44
replace PESps = 6631 if statefip==45
replace PESps = 6191 if statefip==46
replace PESps = 5687 if statefip==47
replace PESps = 6539 if statefip==48
replace PESps = 4674 if statefip==49
replace PESps = 9153 if statefip==50
replace PESps = 7835 if statefip==51

gen LogPESps = ln(PESps)

/* Generate interaction term between log(income+$10) and LogPESps: */
gen interactLogPESpsLogIncome10 = LogPESps * loghhincome10

/* Instruction Expenditure Per Student (2000), Source: National Center for Education Statistics,
* CCD database. */

gen PESTps = 0
replace PESTps = 3629 if statefip==1
replace PESTps = 5300 if statefip==2
replace PESTps = 4493 if statefip==3
replace PESTps = 3127 if statefip==4
replace PESTps = 3400 if statefip==5
replace PESTps = 4343 if statefip==6
replace PESTps = 4007 if statefip==7
replace PESTps = 3755 if statefip==8
replace PESTps = 6469 if statefip==9
replace PESTps = 5448 if statefip==10
replace PESTps = 5982 if statefip==11
replace PESTps = 3600 if statefip==12
replace PESTps = 4394 if statefip==13
replace PESTps = 4629 if statefip==14
replace PESTps = 3973 if statefip==15
replace PESTps = 3511 if statefip==16
replace PESTps = 4554 if statefip==17
replace PESTps = 4700 if statefip==18
replace PESTps = 4059 if statefip==19
replace PESTps = 4072 if statefip==20
replace PESTps = 3725 if statefip==21
replace PESTps = 3638 if statefip==22
replace PESTps = 5506 if statefip==23
replace PESTps = 5071 if statefip==24
replace PESTps = 6307 if statefip==25
replace PESTps = 4832 if statefip==26
replace PESTps = 4748 if statefip==27
replace PESTps = 3126 if statefip==28
replace PESTps = 4039 if statefip==29
replace PESTps = 4150 if statefip==30
replace PESTps = 4504 if statefip==31
replace PESTps = 3628 if statefip==32
replace PESTps = 4733 if statefip==33
replace PESTps = 6668 if statefip==34
replace PESTps = 3511 if statefip==35
replace PESTps = 7274 if statefip==36
replace PESTps = 4024 if statefip==37
replace PESTps = 3645 if statefip==38
replace PESTps = 4428 if statefip==39
replace PESTps = 3483 if statefip==40
replace PESTps = 4424 if statefip==41
replace PESTps = 5127 if statefip==42
replace PESTps = 5109 if statefip==43
replace PESTps = 6007 if statefip==44
replace PESTps = 3968 if statefip==45
replace PESTps = 3671 if statefip==46
replace PESTps = 3664 if statefip==47
replace PESTps = 3952 if statefip==48
replace PESTps = 3024 if statefip==49
replace PESTps = 5930 if statefip==50
replace PESTps = 4738 if statefip==51

gen LogPESTps = ln(PESTps)

/* Generate interaction term between log(income+$10) and LogPESTps: */
gen interactLogPESTpsLogIncome10 = LogPESTps * loghhincome10

/* Estimated average annual salary of teacher in public elementary and secondary schools (2000),
* Source: US Department of Education, National Center for Education Statistics, Digest of Education
* Statistics, Table 78 */

gen TeachSal = 0
replace TeachSal =  37956 if statefip==1
replace TeachSal =  46986 if statefip==2
replace TeachSal =  40197 if statefip==3
replace TeachSal =  36302 if statefip==4
replace TeachSal =  34476 if statefip==5
replace TeachSal =  48923 if statefip==6
replace TeachSal =  42101 if statefip==7
replace TeachSal =  39284 if statefip==8
replace TeachSal =  52100 if statefip==9
replace TeachSal =  47047 if statefip==10
replace TeachSal =  48651 if statefip==11
replace TeachSal =  37824 if statefip==12
replace TeachSal =  42216 if statefip==13
replace TeachSal =  35764 if statefip==14
replace TeachSal =  41980 if statefip==15
replace TeachSal =  36375 if statefip==16
replace TeachSal =  48053 if statefip==17
replace TeachSal =  43055 if statefip==18
replace TeachSal =  36479 if statefip==19
replace TeachSal =  39432 if statefip==20
replace TeachSal =  37234 if statefip==21
replace TeachSal =  34253 if statefip==22
replace TeachSal =  36256 if statefip==23
replace TeachSal =  44997 if statefip==24
replace TeachSal =  47523 if statefip==25
replace TeachSal =  49975 if statefip==26
replace TeachSal =  40577 if statefip==27
replace TeachSal =  32957 if statefip==28
replace TeachSal =  36764 if statefip==29
replace TeachSal =  32930 if statefip==30
replace TeachSal =  34175 if statefip==31
replace TeachSal =  40172 if statefip==32
replace TeachSal =  38303 if statefip==33
replace TeachSal =  53281 if statefip==34
replace TeachSal =  33785 if statefip==35
replace TeachSal =  50920 if statefip==36
replace TeachSal =  41167 if statefip==37
replace TeachSal =  30891 if statefip==38
replace TeachSal =  42716 if statefip==39
replace TeachSal =  34434 if statefip==40
replace TeachSal =  42333 if statefip==41
replace TeachSal =  49500 if statefip==42
replace TeachSal =  41646 if statefip==43
replace TeachSal =  48474 if statefip==44
replace TeachSal =  37327 if statefip==45
replace TeachSal =  30265 if statefip==46
replace TeachSal =  37074 if statefip==47
replace TeachSal =  38614 if statefip==48
replace TeachSal =  36049 if statefip==49
replace TeachSal =  38651 if statefip==50
replace TeachSal =  34189 if statefip==51

gen LogTeachSal = ln(TeachSal)
/* Generate interaction term between log(income+$10) and log of teacher salary: */

gen interactLogTeachSalLogIncome10 = LogTeachSal * loghhincome10

/* To save space, we compress the data set: */
compress

save IPUMSextractHH.dta, replace

/***********/
/* TABLE 1 */
/***********/

/* In what follows we generate all the ingredients in order to compute the correlations presented
* in Table 1 of the paper: */

drop if HHnchild==0

/* Eliminate households in institutions and in other group quarters: */

drop if gq==3
drop if gq==4

/* Observation: It turns out the none of the households in the sample are institutionalized or are
* housed in group quarters. */

/* Average fertility: */

mean(HHnchild), over(statefip)

/* The following command exports the estimates of the mean to the fixed-width text file
* "FertilityByState.txt". These estimates correspond to column D in the "Underlying Variables"
* tab in the "Table 1.xls" spreadsheet, which is also available electronically. */

estout using FertilityByState.txt, style(fixed) cells("b") replace

/* Private school share by state (including only those households who actually have children in
* school): */

drop if kidInSchool==0

mean(private), over(statefip)

/* The following command exports the estimates of the mean to the fixed-width text file
* "SchoolChoiceByState.txt". These estimates correspond to column E in the "Underlying Variables"
* tab in the "Table 1.xls" spreadsheet, which is also available electronically. */

estout using SchoolChoiceByState.txt, style(fixed) cells("b") replace

/***********/
/* TABLE 2 */
/***********/

/* Reload the dataset and proceed to compute the estimates reported in Table 2: */

use IPUMSextractHH.dta, replace

drop if HHnchild==0

/* Eliminate households in institutions and in other group quarters: */

drop if gq==3
drop if gq==4

/* Table 2, Column 1: Ordered logit regression (with clustered standard errors) of fertility on
* dummies, income: */

log using Table2Column1.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 [pweight=hhwt], cluster(statefip)

log close

/* Table 2, Column 2: Ordered logit regression (with clustered standard errors) of fertility on
* dummies, income, and interaction term (public education spending per student): */

log using Table2Column2.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogPESpsLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESps) = 8.89456): */
lincom loghhincome10+interactLogPESpsLogIncome10*8.89456

log close

/* Table 2, Column 3: Ordered logit regression (with clustered standard errors) of fertility on
* dummies, income, and interaction term (public education spending on teaching per student): */

log using Table2Column3.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogPESTpsLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESTps) = 8.40499): */
lincom loghhincome10+interactLogPESTpsLogIncome10*8.40499

log close

/* Table 2, Column 4: Ordered logit regression (with clustered standard errors) of fertility on
*  dummies, income, and interaction term (mean teacher salary): */

log using Table2Column4.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogTeachSalLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogTeachSal) = 10.66123): */
lincom loghhincome10+interactLogTeachSalLogIncome10*10.66123

log close

/***********/
/* TABLE 3 */
/***********/

/* For the school choice regressions, we need to restrict the sample to those households who
* actually have children in school (as opposed to all those with children): */

drop if kidInSchool==0

/* Table 3, Column 1: Logit regression (with clustered standard errors) of school choice on dummies
* and income: */

log using Table3Column1.log, replace

logit private state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 [pweight=hhwt], cluster(statefip)

log close

/* Table 3, Column 2: Logit regression (with clustered standard errors) of school choice on dummies,
* income, and interaction term (public education spending per student): */

log using Table3Column2.log, replace

logit private state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogPESpsLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESps) = 8.89456): */
lincom loghhincome10+interactLogPESpsLogIncome10*8.89456

log close

/* Table 3, Column 3: Logit regression (with clustered standard errors) of school choice on dummies,
* income, and interaction term (public education spending on teaching per student): */

log using Table3Column3.log, replace

logit private state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogPESTpsLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESTps) = 8.40499): */
lincom loghhincome10+interactLogPESTpsLogIncome10*8.40499

log close

/* Table 3, Column 4: Logit regression (with clustered standard errors) of fertility on dummies,
*  income, and interaction term (mean teacher salary): */

log using Table3Column4.log, replace

logit private state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus loghhincome10 interactLogTeachSalLogIncome10 [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogTeachSal) = 10.66123): */
lincom loghhincome10+interactLogTeachSalLogIncome10*10.66123

log close

use IPUMSextractHH, replace

drop if HHnchild==0

drop if gq==3

drop if gq==4

/***************/
/* FOOTNOTE 24 */
/***************/

/* In footnote 24, we hypothesize that rich, white households have "too many" children late in life,
* compared to other racial groups. In what follows, we verify this hypothesis by adding appropriate
* interaction terms to the regressions reported in Table 2.
*
* To verify whether the head of households' age profile of fertility decisions varies systematically
* for whites, we added an interaction term for each age dummy. Namely, the regression includes the
* variables 'ageXWhite' for 20 <= X <= 65 and X = 66plus, in addition to the age dummies included in
*  Table 2.
*
* I also added an interaction term for (school quality) x (log of income) x (white) in addition to
* the interaction term in the regressions reported in Table 2. */


/* Generate the necessary interaction terms: */

forvalues i=20(1)65 {
	gen age`i'White=0
	replace age`i'White=1 if HHHage==`i' & HHHraceWhite==1
}

gen age15_19White = 0
replace age15_19White = 1 if HHHage < 20 & HHHage > 14 & HHHraceWhite==1

gen age66plusWhite = 0
replace age66plusWhite = 1 if HHHage > 65 & HHHraceWhite==1

gen interactLogPESpsLogIncome10Wh = 0
replace interactLogPESpsLogIncome10Wh = interactLogPESpsLogIncome10 if HHHraceWhite==1

gen interactLogPESTpsLogIncome10Wh = 0
replace interactLogPESTpsLogIncome10Wh = interactLogPESTpsLogIncome10 if HHHraceWhite==1

gen interactLogTeachSalLogIncome10Wh = 0
replace interactLogTeachSalLogIncome10Wh = interactLogTeachSalLogIncome10 if HHHraceWhite==1

/* In what follows, we replicate columns 2 through 4 in Table 2, but with the additional interaction
* term discussed above. */

/* Footnote 24, Column 2: Ordered logit regression (with clustered standard errors) of fertility
* on dummies, income, and interaction term (public education spending per student). In addition to
* the regression in Table 2 we add the following interaction terms: (1) 'racwht' interacted with
* each age dummy, and (2) 'racwht' interacted with the interaction term (public education spending
* per student): */

log using Footnote24Column2.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus age20White age21White age22White age23White age24White age25White age26White age27White age28White age29White age30White age31White age32White age33White age34White age35White age36White age37White age38White age39White age40White age41White age42White age43White age44White age45White age46White age47White age48White age49White age50White age51White age52White age53White age54White age55White age56White age57White age58White age59White age60White age61White age62White age63White age64White age65White age66plusWhite loghhincome10 interactLogPESpsLogIncome10 interactLogPESpsLogIncome10Wh [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESps) = 8.89456): */
lincom loghhincome10+interactLogPESpsLogIncome10*8.89456

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESps) = 8.89456) for white households only: */
lincom loghhincome10+(interactLogPESpsLogIncome10+interactLogPESpsLogIncome10Wh)*8.89456

log close

/* Footnote 24, Column 3: Ordered logit regression (with clustered standard errors) of fertility on
* dummies, income, and interaction term (public education spending on teaching per student). In
* addition to the regression in Table 2 we add the following interaction terms: (1) 'racwht'
* interacted with each age dummy, and (2) 'racwht' interacted with the interaction term (public
* education spending per student): */

log using Footnote24Column3.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus age20White age21White age22White age23White age24White age25White age26White age27White age28White age29White age30White age31White age32White age33White age34White age35White age36White age37White age38White age39White age40White age41White age42White age43White age44White age45White age46White age47White age48White age49White age50White age51White age52White age53White age54White age55White age56White age57White age58White age59White age60White age61White age62White age63White age64White age65White age66plusWhite loghhincome10 interactLogPESTpsLogIncome10 interactLogPESTpsLogIncome10Wh [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESTps) = 8.40499): */
lincom loghhincome10+interactLogPESTpsLogIncome10*8.40499

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogPESTps) = 8.40499) for white households only: */
lincom loghhincome10+(interactLogPESTpsLogIncome10+interactLogPESTpsLogIncome10Wh)*8.40499

log close

/* Footnote 24, Column 4: Ordered logit regression (with clustered standard errors) of fertility on
* dummies, income, and interaction term (mean teacher salary). In addition to the regression in
* Table 2 we add the following interaction terms: (1) 'racwht' interacted with each age dummy, and
* (2) 'racwht' interacted with the interaction term (public education spending per student): */

log using Footnote24Column4.log, replace

ologit HHnchild state2 state3 state4 state5 state6 state7 state8 state9 state10 state11 state12 state13 state14 state15 state16 state17 state18 state19 state20 state21 state22 state23 state24 state25 state26 state27 state28 state29 state30 state31 state32 state33 state34 state35 state36 state37 state38 state39 state40 state41 state42 state43 state44 state45 state46 state47 state48 state49 state50 state51 age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32 age33 age34 age35 age36 age37 age38 age39 age40 age41 age42 age43 age44 age45 age46 age47 age48 age49 age50 age51 age52 age53 age54 age55 age56 age57 age58 age59 age60 age61 age62 age63 age64 age65 age66plus age20White age21White age22White age23White age24White age25White age26White age27White age28White age29White age30White age31White age32White age33White age34White age35White age36White age37White age38White age39White age40White age41White age42White age43White age44White age45White age46White age47White age48White age49White age50White age51White age52White age53White age54White age55White age56White age57White age58White age59White age60White age61White age62White age63White age64White age65White age66plusWhite loghhincome10 interactLogTeachSalLogIncome10 interactLogTeachSalLogIncome10Wh [pweight=hhwt], cluster(statefip)

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogTeachSal) = 10.66123): */
lincom loghhincome10+interactLogTeachSalLogIncome10*10.66123

/* Total effect of income and school quality (evaluated at mean school quality,
* i.e. mean(LogTeachSal) = 10.66123) for white households only: */
lincom loghhincome10+(interactLogTeachSalLogIncome10+interactLogTeachSalLogIncome10Wh)*10.66123

log close

/* Note: The estimates confirm the hypothesis formulated in footnote 24.
* The coefficients on these additional interaction terms are statistically significant
* (t-statistic >= 8) and negative. In other words, white heads of household tend to have fewer of
* their own children at home compared to non-whites in all age groups.
*
* The fertility gap is narrowest for white heads of households in their 40s.
*
* The estimated coefficients on these "interacted interaction terms" are positive and statistically
* significant in all three regressions. In other words, the coefficient on the `original'
* interaction term varies systematically between white and non-white households.
*
* The difference is such that the total effect of income is positive for white heads of
* household and negative for non-whites. */

